//	eMalice Metal Shader - 1.1
//------------------------------------
float4x4 WorldViewProj : WorldViewProjection;
float4x4 WorldIT : WorldIT;
float4 EyePos : EyePos;

//------------------------------------
texture BaseMap
<
	string name = "Metal.tga";
>;

texture NormalMap
<
	string name = "MetalNormal.tga";
>;

texture ShineMap
<
	string name = "MetalShine.tga";
>;

//------------------------------------
technique metal
{
	pass p0 
	{		
		VertexShaderConstant[0] = <WorldViewProj>;
		VertexShaderConstant[4] = <WorldIT>;
		VertexShaderConstant[8] = <EyePos>;

		VertexShader = asm
		{
			// Initilise Shader
			vs.1.1
			dcl_position	v0
			dcl_normal		v1
			dcl_tangent		v2
			dcl_binormal	v3
			dcl_texcoord	v4
			def c20, 0.0f, 1.0f, 1.0f, 1.0f
			
			// Transform Position to Clip
			m4x4 oPos, v0, c0
			
			// Output Tex Coords
			mov oT0, v4
			mov oT1, v4
						
			// Move Eye Position to Object Space
			mov r0, c8
			m4x4 r1, r0, c4
			
			// Compute Eye Vector
			sub r1, r1, v0
			
			// Normalise Eye Vector
			dp3 r1.w, r1, r1
			rsq r1.w, r1.w
			mul r1, r1, r1.w
			
			// Move Light Vector to Texture Space
			dp3 r2.x, r1, v2
			dp3 r2.y, r1, v3
			dp3 r2.z, r1, v1
			
			// Output Eye Vector
			mov oT2, r2.xyz
		};
		
		PixelShader = asm
		{
			// Initialise Shader
			ps.1.1
			
			// Base Map and Normal Map
			tex t0
			tex t1
			
			// N-dot-E and load from Lookup Texture
			texm3x2pad t2, t1_bx2
			texm3x2tex t3, t1_bx2
			
			// Add Shine to Base
			add r0, t0, t3
		};

		Texture[0] = <BaseMap>;
		MinFilter[0] = Linear;
		MagFilter[0] = Linear;
		MipFilter[0] = Linear;

		Texture[1] = <NormalMap>;
		MinFilter[1] = Linear;
		MagFilter[1] = Linear;
		MipFilter[1] = Linear;

		Texture[3] = <ShineMap>;
		MinFilter[3] = Linear;
		MagFilter[3] = Linear;
		MipFilter[3] = Linear;
	}
};